@@ -5,7 +5,7 @@ import tarfile
 import json
 import tempfile
 from subprocess import Popen, PIPE
-from _distro import findDistroType
+from ._distro import findDistroType
 
 discordDictionary = {
     "stable": {
